@@ -4,4 +4,4 @@ require_relative "../lib/tty-prompt"
 
 prompt = TTY::Prompt.new
 
-prompt.ask("What\nis your\nname?", default: ENV['USER'])
+prompt.ask("What\nis your\nname?", default: ENV["USER"])
