@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require_relative '../lib/tty-prompt'
+require_relative "../lib/tty-prompt"
 
 prompt = TTY::Prompt.new
 
@@ -10,6 +10,6 @@ quotes = [
   "There is a wisdom that is woe; but there is a woe that is madness. And there is a Catskill eagle in some souls that can alike dive down into the blackest gorges, and soar out of them again and become invisible in the sunny spaces. And even if he for ever flies within the gorge, that gorge is in the mountains; so that even in his lowest swoop the mountain eagle is still higher than other birds upon the plain, even though they soar."
 ]
 
-answer = prompt.select('Chose your quote?', quotes)
+answer = prompt.select("Chose your quote?", quotes)
 
 puts "Answer: #{answer}"
