@@ -4,6 +4,6 @@ require_relative "../lib/tty-prompt"
 
 prompt = TTY::Prompt.new
 
-prompt.ask('What is your username?') do |q|
-  q.validate(/^[^\.]+\.[^\.]+/)
+prompt.ask("What is your username?") do |q|
+  q.validate(/\A[^.]+\.[^.]+\Z/)
 end
