@@ -1,18 +1,26 @@
 # frozen_string_literal: true
 
-RSpec.describe TTY::Prompt::Question, 'convert date' do
+RSpec.describe TTY::Prompt::Question, "convert date" do
+  subject(:prompt) { TTY::Prompt::Test.new }
 
-  subject(:prompt) { TTY::TestPrompt.new}
-
-  it 'fails to convert date' do
-    prompt.input << 'invalid'
+  it "fails to convert date" do
+    prompt.input << "x"
     prompt.input.rewind
-    expect {
-      prompt.ask("When were you born?", convert: :date)
-    }.to raise_error(TTY::Prompt::ConversionError)
+    prompt.ask("When were you born?", convert: :date)
+
+    expect(prompt.output.string).to eq([
+      "When were you born? ",
+      "\e[2K\e[1G",
+      "When were you born? x",
+      "\e[31m>>\e[0m Cannot convert `x` to 'date' type",
+      "\e[1A\e[2K\e[1G",
+      "When were you born? ",
+      "\e[2K\e[1G\e[1A\e[2K\e[1G",
+      "When were you born? \n"
+    ].join)
   end
 
-  it 'converts date' do
+  it "converts date" do
     prompt.input << "20th April 1887"
     prompt.input.rewind
     response = prompt.ask("When were your born?", convert: :date)
