@@ -1,8 +1,8 @@
 # frozen_string_literal: true
 
-RSpec.describe TTY::Prompt::Question, 'convert regexp' do
+RSpec.describe TTY::Prompt::Question, "convert regexp" do
   it "converts regex" do
-    prompt = TTY::TestPrompt.new
+    prompt = TTY::Prompt::Test.new
     prompt.input << "[a-z]*"
     prompt.input.rewind
     answer = prompt.ask("Regex?", convert: :regexp)
