@@ -3,13 +3,15 @@
 RSpec.describe TTY::Prompt do
   let(:symbols) { TTY::Prompt::Symbols.symbols }
 
+  subject(:prompt) { TTY::Prompt::Test.new }
+
   def output_helper(prompt, choices, active, options = {})
-    enum    = options.fetch(:enum, ')')
+    enum    = options.fetch(:enum, ")")
     input   = options[:input]
     error   = options[:error]
     default = options.fetch(:default, 1)
 
-    out  = []
+    out = []
     out << prompt << " \n"
     out << choices.map.with_index do |c, i|
       name = c.is_a?(Hash) ? c[:name] : c
@@ -25,7 +27,7 @@ RSpec.describe TTY::Prompt do
     end.join("\n")
     out << "\n"
     choice =  "  Choose 1-#{choices.count} [#{default}]: "
-    choice = choice + input.to_s if input
+    choice += input.to_s if input
     out << choice
     if error
       out << "\n"
@@ -41,9 +43,8 @@ RSpec.describe TTY::Prompt do
     "#{prompt} \e[32m#{choice}\e[0m\n"
   end
 
-  it "raises configuration error when wrong default" do
-    prompt = TTY::TestPrompt.new
-    choices = %w(/bin/nano /usr/bin/vim.basic /usr/bin/vim.tiny)
+  it "raises configuration error when default is higher than number of choices" do
+    choices = %w[/bin/nano /usr/bin/vim.basic /usr/bin/vim.tiny]
 
     expect {
       prompt.enum_select("Select an editor?", choices, default: 100)
@@ -51,14 +52,43 @@ RSpec.describe TTY::Prompt do
                      /default index 100 out of range \(1 - 3\)/)
   end
 
+  it "selects default choice by name" do
+    choices = %w[/bin/nano /usr/bin/vim.basic /usr/bin/vim.tiny]
+    prompt.input << "\n"
+    prompt.input.rewind
+
+    answer = prompt.enum_select("Select an editor?", choices,
+                                default: "/usr/bin/vim.basic")
+
+    expect(answer).to eq("/usr/bin/vim.basic")
+  end
+
+  it "raises when default choice name is not found" do
+    choices = %w[/bin/nano /usr/bin/vim.basic /usr/bin/vim.tiny]
+
+    expect {
+      prompt.enum_select("Select an editor?", choices, default: "unknown")
+    }.to raise_error(TTY::Prompt::ConfigurationError,
+                     "no choice found for the default name: \"unknown\"")
+  end
+
+  it "raises when default name matches a disabled choice" do
+    choices = [{name: "/bin/nano", disabled: "unavailable"},
+               "/usr/bin/vim.basic", "/usr/bin/vim.tiny"]
+
+    expect {
+      prompt.enum_select("Select an editor?", choices, default: "/bin/nano")
+    }.to raise_error(TTY::Prompt::ConfigurationError,
+                     "default name \"/bin/nano\" matches disabled choice")
+  end
+
   it "selects default option when return pressed immediately" do
-    choices = %w(/bin/nano /usr/bin/vim.basic /usr/bin/vim.tiny)
-    prompt = TTY::TestPrompt.new
+    choices = %w[/bin/nano /usr/bin/vim.basic /usr/bin/vim.tiny]
     prompt.input << "\n"
     prompt.input.rewind
 
     answer = prompt.enum_select("Select an editor?", choices)
-    expect(answer).to eq('/bin/nano')
+    expect(answer).to eq("/bin/nano")
 
     expected_output = [
       output_helper("Select an editor?", choices, "/bin/nano"),
@@ -69,17 +99,16 @@ RSpec.describe TTY::Prompt do
   end
 
   it "selects option by index from the list" do
-    choices = %w(/bin/nano /usr/bin/vim.basic /usr/bin/vim.tiny)
-    prompt = TTY::TestPrompt.new
+    choices = %w[/bin/nano /usr/bin/vim.basic /usr/bin/vim.tiny]
     prompt.input << "3\n"
     prompt.input.rewind
 
     answer = prompt.enum_select("Select an editor?", choices, default: 2)
-    expect(answer).to eq('/usr/bin/vim.tiny')
+    expect(answer).to eq("/usr/bin/vim.tiny")
 
     expected_output = [
       output_helper("Select an editor?", choices, "/usr/bin/vim.basic", default: 2),
-      output_helper("Select an editor?", choices, "/usr/bin/vim.tiny", default: 2, input: '3'),
+      output_helper("Select an editor?", choices, "/usr/bin/vim.tiny", default: 2, input: "3"),
       exit_message("Select an editor?", "/usr/bin/vim.tiny")
     ].join
 
@@ -87,44 +116,64 @@ RSpec.describe TTY::Prompt do
   end
 
   it "selects option through DSL" do
-    choices = %w(/bin/nano /usr/bin/vim.basic /usr/bin/vim.tiny)
-    prompt = TTY::TestPrompt.new
+    choices = %w[/bin/nano /usr/bin/vim.basic /usr/bin/vim.tiny]
     prompt.input << "1\n"
     prompt.input.rewind
     answer = prompt.enum_select("Select an editor?") do |menu|
       menu.default 2
-      menu.enum '.'
+      menu.enum "."
 
       menu.choice "/bin/nano"
       menu.choice "/usr/bin/vim.basic"
       menu.choice "/usr/bin/vim.tiny"
     end
-    expect(answer).to eq('/bin/nano')
+    expect(answer).to eq("/bin/nano")
 
     expected_output = [
-      output_helper("Select an editor?", choices, "/usr/bin/vim.basic", default: 2, enum: '.'),
-      output_helper("Select an editor?", choices, "/bin/nano", default: 2, enum: '.', input: 1),
+      output_helper("Select an editor?", choices, "/usr/bin/vim.basic", default: 2, enum: "."),
+      output_helper("Select an editor?", choices, "/bin/nano", default: 2, enum: ".", input: 1),
       exit_message("Select an editor?", "/bin/nano")
     ].join
 
     expect(prompt.output.string).to eq(expected_output)
   end
 
+  it "sets choice value to nil through DSL" do
+    choices = %w[none /bin/nano /usr/bin/vim.basic /usr/bin/vim.tiny]
+    prompt.input << "\n"
+    prompt.input.rewind
+    answer = prompt.enum_select("Select an editor?") do |menu|
+      menu.default 1
+
+      menu.choice "none", nil
+      menu.choice "/bin/nano"
+      menu.choice "/usr/bin/vim.basic"
+      menu.choice "/usr/bin/vim.tiny"
+    end
+    expect(answer).to eq(nil)
+
+    expected_output = [
+      output_helper("Select an editor?", choices, "none", default: 1),
+      exit_message("Select an editor?", "none")
+    ].join
+
+    expect(prompt.output.string).to eq(expected_output)
+  end
+
   it "selects option through DSL with key and value" do
-    choices = %w(nano vim emacs)
-    prompt = TTY::TestPrompt.new
+    choices = %w[nano vim emacs]
     prompt.input << "\n"
     prompt.input.rewind
 
     answer = prompt.enum_select("Select an editor?") do |menu|
       menu.default 2
 
-      menu.choice :nano,  '/bin/nano'
-      menu.choice :vim,   '/usr/bin/vim'
-      menu.choice :emacs, '/usr/bin/emacs'
+      menu.choice :nano,  "/bin/nano"
+      menu.choice :vim,   "/usr/bin/vim"
+      menu.choice :emacs, "/usr/bin/emacs"
     end
 
-    expect(answer).to eq('/usr/bin/vim')
+    expect(answer).to eq("/usr/bin/vim")
 
     expected_output = [
       output_helper("Select an editor?", choices, "vim", default: 2),
@@ -135,15 +184,14 @@ RSpec.describe TTY::Prompt do
   end
 
   it "changes colors for selection, hint and error" do
-    prompt = TTY::TestPrompt.new
-    choices = %w(/bin/nano /usr/bin/vim.basic /usr/bin/vim.tiny)
+    choices = %w[/bin/nano /usr/bin/vim.basic /usr/bin/vim.tiny]
     prompt.input << "\n"
     prompt.input.rewind
     options = {active_color: :red, help_color: :blue, error_color: :green}
 
     answer = prompt.enum_select("Select an editor?", choices, options)
 
-    expect(answer).to eq('/bin/nano')
+    expect(answer).to eq("/bin/nano")
 
     expected_output = [
       "Select an editor? \n",
@@ -160,8 +208,8 @@ RSpec.describe TTY::Prompt do
   end
 
   it "changes global symbols" do
-    prompt = TTY::TestPrompt.new(symbols: {cross: 'x'})
-    choices = ['A', {name: 'B', disabled: '(out)'}, 'C']
+    prompt = TTY::Prompt::Test.new(symbols: {cross: "x"})
+    choices = ["A", {name: "B", disabled: "(out)"}, "C"]
     prompt.input << "\n"
     prompt.input.rewind
     answer = prompt.enum_select("What letter?", choices)
@@ -175,19 +223,18 @@ RSpec.describe TTY::Prompt do
       "  Choose 1-3 [1]: ",
       "\e[2K\e[1G\e[1A" * 4,
       "\e[2K\e[1G\e[J",
-      "What letter? \e[32mA\e[0m\n",
+      "What letter? \e[32mA\e[0m\n"
     ].join
 
     expect(prompt.output.string).to eq(expected_output)
   end
 
   it "changes global symbols through DSL" do
-    prompt = TTY::TestPrompt.new
-    choices = ['A', {name: 'B', disabled: '(out)'}, 'C']
+    choices = ["A", {name: "B", disabled: "(out)"}, "C"]
     prompt.input << "\n"
     prompt.input.rewind
-    answer = prompt.enum_select("What letter?", choices) do |menu|
-               menu.symbols cross: 'x'
+    answer = prompt.enum_select("What letter?") do |menu|
+               menu.symbols cross: "x"
                menu.choices choices
              end
     expect(answer).to eq("A")
@@ -200,27 +247,63 @@ RSpec.describe TTY::Prompt do
       "  Choose 1-3 [1]: ",
       "\e[2K\e[1G\e[1A" * 4,
       "\e[2K\e[1G\e[J",
-      "What letter? \e[32mA\e[0m\n",
+      "What letter? \e[32mA\e[0m\n"
     ].join
 
     expect(prompt.output.string).to eq(expected_output)
   end
 
+  it "sets quiet mode" do
+    choices = %w[/bin/nano /usr/bin/vim.basic /usr/bin/vim.tiny]
+    prompt = TTY::Prompt::Test.new(quiet: true)
+    prompt.input << "\n"
+    prompt.input.rewind
+
+    answer = prompt.enum_select("Select an editor?", choices)
+    expect(answer).to eq("/bin/nano")
+
+    expected_output =
+      output_helper("Select an editor?", choices, "/bin/nano")
+
+    expect(prompt.output.string).to eq(expected_output)
+  end
+
+  it "sets quiet mode through DSL" do
+    choices = %w[/bin/nano /usr/bin/vim.basic /usr/bin/vim.tiny]
+    prompt.input << "1\n"
+    prompt.input.rewind
+    answer = prompt.enum_select("Select an editor?") do |menu|
+      menu.quiet true
+      menu.default 2
+      menu.enum "."
+
+      menu.choice "/bin/nano"
+      menu.choice "/usr/bin/vim.basic"
+      menu.choice "/usr/bin/vim.tiny"
+    end
+    expect(answer).to eq("/bin/nano")
+
+    expected_output =
+      output_helper("Select an editor?", choices, "/usr/bin/vim.basic", default: 2, enum: ".") +
+      output_helper("Select an editor?", choices, "/bin/nano", default: 2, enum: ".", input: 1)
+
+    expect(prompt.output.string).to eq(expected_output)
+  end
+
   it "displays error with unrecognized input" do
-    choices = %w(/bin/nano /usr/bin/vim.basic /usr/bin/vim.tiny)
-    prompt = TTY::TestPrompt.new
+    choices = %w[/bin/nano /usr/bin/vim.basic /usr/bin/vim.tiny]
     prompt.input << "11\n2\n"
     prompt.input.rewind
 
     answer = prompt.enum_select("Select an editor?", choices)
-    expect(answer).to eq('/usr/bin/vim.basic')
+    expect(answer).to eq("/usr/bin/vim.basic")
 
     expected_output = [
       output_helper("Select an editor?", choices, "/bin/nano"),
-      output_helper("Select an editor?", choices, "/bin/nano", input: '1'),
-      output_helper("Select an editor?", choices, "/bin/nano", input: '11'),
-      output_helper("Select an editor?", choices, "/bin/nano", error: 'Please enter a valid number', input: ''),
-      output_helper("Select an editor?", choices, "/usr/bin/vim.basic", error: 'Please enter a valid number', input: '2'),
+      output_helper("Select an editor?", choices, "/bin/nano", input: "1"),
+      output_helper("Select an editor?", choices, "/bin/nano", input: "11"),
+      output_helper("Select an editor?", choices, "/bin/nano", error: "Please enter a valid number", input: ""),
+      output_helper("Select an editor?", choices, "/usr/bin/vim.basic", error: "Please enter a valid number", input: "2"),
       exit_message("Select an editor?", "/usr/bin/vim.basic")
     ].join
 
@@ -228,13 +311,12 @@ RSpec.describe TTY::Prompt do
   end
 
   it "paginates long selections" do
-    choices = %w(A B C D E F G H)
-    prompt = TTY::TestPrompt.new
+    choices = %w[A B C D E F G H]
     prompt.input << "\n"
     prompt.input.rewind
 
     answer = prompt.enum_select("What letter?", choices, per_page: 3, default: 4)
-    expect(answer).to eq('D')
+    expect(answer).to eq("D")
 
     expect(prompt.output.string).to eq([
       "What letter? \n",
@@ -251,8 +333,7 @@ RSpec.describe TTY::Prompt do
   end
 
   it "doesn't paginate short selections" do
-    choices = %i(A B C D)
-    prompt = TTY::TestPrompt.new
+    choices = %i[A B C D]
     prompt.input << "\r"
     prompt.input.rewind
 
@@ -267,12 +348,11 @@ RSpec.describe TTY::Prompt do
   end
 
   it "shows pages matching input" do
-    prompt = TTY::TestPrompt.new
-    choices = %w(A B C D E F G H)
+    choices = %w[A B C D E F G H]
     prompt.input << "11\n\b\n"
     prompt.input.rewind
     value = prompt.enum_select("What letter?", choices, per_page: 3)
-    expect(value).to eq('A')
+    expect(value).to eq("A")
     expect(prompt.output.string).to eq([
       "What letter? \n",
       "  \e[32m1) A\e[0m\n",
@@ -326,8 +406,7 @@ RSpec.describe TTY::Prompt do
   end
 
   it "switches through pages with tab key" do
-    prompt = TTY::TestPrompt.new
-    choices = %w(A B C D E F G H)
+    choices = %w[A B C D E F G H]
     prompt.input << "\t\n"
     prompt.input.rewind
     value = prompt.enum_select("What letter?") do |menu|
@@ -335,7 +414,7 @@ RSpec.describe TTY::Prompt do
               menu.per_page 3
               menu.choices choices
             end
-    expect(value).to eq('D')
+    expect(value).to eq("D")
     expect(prompt.output.string).to eq([
       "What letter? \n",
       "  \e[32m4) D\e[0m\n",
@@ -359,8 +438,7 @@ RSpec.describe TTY::Prompt do
   end
 
   it "doesn't cycle around by default" do
-    prompt = TTY::TestPrompt.new
-    choices = %w(A B C D E F)
+    choices = %w[A B C D E F]
     prompt.input << "\t" << "\t" << "\n"
     prompt.input.rewind
     value = prompt.enum_select("What letter?") do |menu|
@@ -402,8 +480,7 @@ RSpec.describe TTY::Prompt do
   end
 
   it "cycles around when configured to do so" do
-    prompt = TTY::TestPrompt.new
-    choices = %w(A B C D E F)
+    choices = %w[A B C D E F]
     prompt.input << "\t" << "\t" << "\n"
     prompt.input.rewind
     value = prompt.enum_select("What letter?", cycle: true) do |menu|
@@ -447,8 +524,7 @@ RSpec.describe TTY::Prompt do
 
   context "with :disabled choice" do
     it "fails when active item is also disabled" do
-      prompt = TTY::TestPrompt.new
-      choices = [{name: 'A', disabled: true}, 'B', 'C', 'D', 'E']
+      choices = [{name: "A", disabled: true}, "B", "C", "D", "E"]
       expect {
         prompt.enum_select("What letter?", choices, default: 1)
       }.to raise_error(TTY::Prompt::ConfigurationError,
@@ -456,19 +532,16 @@ RSpec.describe TTY::Prompt do
     end
 
     it "finds first non-disabled index" do
-      prompt = TTY::TestPrompt.new
-      choices = [{name: 'A', disabled: true}, {name:'B', disabled: true}, 'C', 'D']
-      prompt = TTY::TestPrompt.new
+      choices = [{name: "A", disabled: true}, {name: "B", disabled: true}, "C", "D"]
       prompt.input << "\n"
       prompt.input.rewind
 
       answer = prompt.enum_select("What letter?", choices)
-      expect(answer).to eq('C')
+      expect(answer).to eq("C")
     end
 
     it "doesn't allow to choose disabled choice and defaults" do
-      choices = ['A', {name: 'B', disabled: '(out)'}, 'C', 'D', 'E', 'F']
-      prompt = TTY::TestPrompt.new
+      choices = ["A", {name: "B", disabled: "(out)"}, "C", "D", "E", "F"]
       prompt.input << "2" << "\n" << "3" << "\n"
       prompt.input.rewind
 
@@ -476,10 +549,10 @@ RSpec.describe TTY::Prompt do
       expect(answer).to eq("C")
 
       expected_output = [
-        output_helper("What letter?", choices, 'A'),
-        output_helper("What letter?", choices, 'A', input: '2'),
-        output_helper("What letter?", choices, 'A', input: '', error: 'Please enter a valid number'),
-        output_helper("What letter?", choices, 'C', input: '3', error: 'Please enter a valid number'),
+        output_helper("What letter?", choices, "A"),
+        output_helper("What letter?", choices, "A", input: "2"),
+        output_helper("What letter?", choices, "A", input: "", error: "Please enter a valid number"),
+        output_helper("What letter?", choices, "C", input: "3", error: "Please enter a valid number"),
         exit_message("What letter?", "C")
       ].join
 
@@ -488,27 +561,26 @@ RSpec.describe TTY::Prompt do
 
     it "omits disabled choice when navigating with numbers" do
       choices = [
-        {name: 'A'},
-        {name: 'B', disabled: '(out)'},
-        {name: 'C', disabled: '(out)'},
-        {name: 'D'},
-        {name: 'E'}
+        {name: "A"},
+        {name: "B", disabled: "(out)"},
+        {name: "C", disabled: "(out)"},
+        {name: "D"},
+        {name: "E"}
       ]
-      prompt = TTY::TestPrompt.new
-      prompt.on(:keypress) { |e| prompt.trigger(:keydelete) if e.value == "B"}
-      prompt.input << "2" << "\u007F" << "3" << "\u007F" << '4' << "\n"
+      prompt.on(:keypress) { |e| prompt.trigger(:keydelete) if e.value == "B" }
+      prompt.input << "2" << "\u007F" << "3" << "\u007F" << "4" << "\n"
       prompt.input.rewind
 
       answer = prompt.enum_select("What letter?", choices)
       expect(answer).to eq("D")
 
       expected_output = [
-        output_helper("What letter?", choices, 'A'),
-        output_helper("What letter?", choices, 'A', input: '2'),
-        output_helper("What letter?", choices, 'A', input: ''),
-        output_helper("What letter?", choices, 'A', input: '3'),
-        output_helper("What letter?", choices, 'A', input: ''),
-        output_helper("What letter?", choices, 'D', input: '4'),
+        output_helper("What letter?", choices, "A"),
+        output_helper("What letter?", choices, "A", input: "2"),
+        output_helper("What letter?", choices, "A", input: ""),
+        output_helper("What letter?", choices, "A", input: "3"),
+        output_helper("What letter?", choices, "A", input: ""),
+        output_helper("What letter?", choices, "D", input: "4"),
         exit_message("What letter?", "D")
       ].join
 
