@@ -1,9 +1,9 @@
 # frozen_string_literal: true
 
-RSpec.describe TTY::Prompt, '#subscribe' do
+RSpec.describe TTY::Prompt, "#subscribe" do
   it "subscribes to key events only for the current prompt" do
-    prompt = TTY::TestPrompt.new
-    uuid = '14c3b412-e0c5-4ff5-9cd8-25ec3f18c702'
+    prompt = TTY::Prompt::Test.new
+    uuid = "14c3b412-e0c5-4ff5-9cd8-25ec3f18c702"
     prompt.input << "3\n#{uuid}\n"
     prompt.input.rewind
     keys = []
@@ -12,11 +12,11 @@ RSpec.describe TTY::Prompt, '#subscribe' do
       keys << :enter if event.key.name == :enter
     end
 
-    letter = prompt.enum_select('Select something', ('A'..'Z').to_a)
-    id = prompt.ask('Request ID?')
+    letter = prompt.enum_select("Select something", ("A".."Z").to_a)
+    id = prompt.ask("Request ID?")
 
-    expect(letter).to eq('C')
+    expect(letter).to eq("C")
     expect(id).to eq(uuid)
-    expect(keys).to eq([:enter, :enter])
+    expect(keys).to eq(%i[enter enter])
   end
 end
